@@ -53,7 +53,7 @@ class CMS(HSApi):
         return translated_data
 
 
-class COS(Blog):
+class COS(HSApi):
     URL = "https://api.hubapi.com/blog/v2"
 
     def post(self, data, target_portal):
